//! Data Types and functions related to math with focus on vectors.

pub use hit::Hit;
pub use ray::Ray;
pub use vec3::Vec3;

mod hit;
mod ray;
mod vec3;
